"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const nodepath = require("path");
const node_filter_async_1 = require("node-filter-async");
const mkdirp = require('mkdirp-promise');
const { promisify } = require('bluebird');
const unsafeWriteFileAsync = promisify(fs.writeFile);
exports.readFileAsync = promisify(fs.readFile);
exports.statAsync = promisify(fs.stat);
exports.readdirAsync = promisify(fs.readdir);
function readTextFileAsync(path) {
    return __awaiter(this, void 0, void 0, function* () {
        return yield exports.readFileAsync(path, 'utf8');
    });
}
exports.readTextFileAsync = readTextFileAsync;
function writeFileAsync(path, data, options) {
    return __awaiter(this, void 0, void 0, function* () {
        const dirPath = nodepath.dirname(path);
        yield mkdirp(dirPath);
        yield unsafeWriteFileAsync(path, data, options);
    });
}
exports.writeFileAsync = writeFileAsync;
function statOrNullAsync(path) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            return yield exports.statAsync(path);
        }
        catch (_a) {
            return null;
        }
    });
}
exports.statOrNullAsync = statOrNullAsync;
function fileExists(path) {
    return __awaiter(this, void 0, void 0, function* () {
        const stat = yield statOrNullAsync(path);
        if (stat && stat.isFile()) {
            return true;
        }
        return false;
    });
}
exports.fileExists = fileExists;
function dirExists(path) {
    return __awaiter(this, void 0, void 0, function* () {
        const stat = yield statOrNullAsync(path);
        if (stat && stat.isDirectory()) {
            return true;
        }
        return false;
    });
}
exports.dirExists = dirExists;
function listSubPaths(path, options) {
    return __awaiter(this, void 0, void 0, function* () {
        return yield exports.readdirAsync(path, options).then((files) => {
            return files.map((file) => nodepath.join(path, file));
        });
    });
}
exports.listSubPaths = listSubPaths;
function listSubDirs(dir) {
    return __awaiter(this, void 0, void 0, function* () {
        const paths = yield listSubPaths(dir);
        const dirs = yield node_filter_async_1.filterAsync(paths, (path) => __awaiter(this, void 0, void 0, function* () {
            const stat = yield exports.statAsync(path);
            return stat.isDirectory();
        }));
        return dirs;
    });
}
exports.listSubDirs = listSubDirs;
function listSubFiles(dir) {
    return __awaiter(this, void 0, void 0, function* () {
        const paths = yield exports.readdirAsync(dir);
        const dirs = yield node_filter_async_1.filterAsync(paths, (path) => __awaiter(this, void 0, void 0, function* () {
            const stat = yield exports.statAsync(path);
            return stat.isFile();
        }));
        return dirs;
    });
}
exports.listSubFiles = listSubFiles;
//# sourceMappingURL=mfs.js.map